configure_bar: Configure The Progress Bar

configure_barR Documentation

Configure The Progress Bar

Description

This function can be used to conveniently configure the progress bar. It is exported for convenience from the parabar::parabar package. Please consult its documentation at parabar::configure_bar for more information on how to use it.

Usage

    configure_bar(type = "modern", ...)

Arguments

type

A character string specifying the type of progress bar to be used with compatible backends. Possible values are "modern" and "basic". The default value is "modern".

...

A list of named arguments used to configure the progress bar. See the Details section for more information.


parSim documentation built on Feb. 26, 2026, 5:06 p.m.