parSim-package: Parallel Simulation Studies

parSim-packageR Documentation

Parallel Simulation Studies

Description

Perform flexible simulation studies using one or multiple computer cores. The package is set up to be usable on high-performance clusters in addition to being run locally (i.e., see the package vignettes for more information).

Author(s)

Maintainer: Sacha Epskamp mail@sachaepskamp.com (ORCID) (https://sachaepskamp.com)

Authors:

Other contributors:

See Also

Useful links:


parSim documentation built on Feb. 26, 2026, 5:06 p.m.