| configure_bar | R Documentation |
This function can be used to conveniently configure the progress bar. It is
exported for convenience from the
parabar::parabar package. Please
consult its documentation at
parabar::configure_bar for more
information on how to use it.
configure_bar(type = "modern", ...)
type |
A character string specifying the type of progress bar to be used with
compatible |
... |
A list of named arguments used to configure the progress bar. See the Details section for more information. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.