| parSim-package | R Documentation |
Perform flexible simulation studies using one or multiple computer cores. The package is set up to be usable on high-performance clusters in addition to being run locally (i.e., see the package vignettes for more information).
Maintainer: Sacha Epskamp mail@sachaepskamp.com (ORCID) (https://sachaepskamp.com)
Authors:
Mihai Constantin mihai@mihaiconstantin.com (ORCID) (https://mihaiconstantin.com)
Other contributors:
Xinkai Du xinkai.du.xd@gmail.com [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.