| parSim_dt | R Documentation |
The function uses the more efficient data.table in its internal code instead of dplyr, thereby speeding up the function itself and also allowing researchers to use data.table to speed up the code they want to simulate with parSim.
parSim_dt(
...,
expression,
reps = 1,
write = FALSE,
name,
nCores = 1,
export,
exclude,
debug = FALSE,
progressbar = TRUE,
env = parent.frame()
)
... |
Any number of |
expression |
An |
reps |
Integer. The number of replications for each condition. Defaults to |
write |
Logical, should the results be written to a file instead of returned as
a data frame? If |
name |
Name of the file if |
nCores |
An integer value indicating the number of cores to use for parallel
execution. Defaults to |
export |
A character vector of global objects to export to the cluster. |
exclude |
A character vector of logical expressions to exclude cases. These are
combined with |
debug |
Logical. If |
progressbar |
Logical. If |
env |
The environment from which to export variables specified in the
|
The function uses data.table in its internal code instead of dplyr, thereby speeding up the simulation and allowing researchers to use data.table in the code they want to simulate with parSim.
A data.table with the results of each
iteration in each row. Returns NULL if write = TRUE.
Xinkai Du <xinkai.du.xd@gmail.com>
parSim
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.